# Abstraction Planes
Simplify complex systems with a 6-plane stack from Intent to Metal.

[![Build Status](https://img.shields.io/travis/SuperInstance/abstraction-planes)](https://travis-ci.org/SuperInstance/abstraction-planes)
[![License](https://img.shields.io/github/license/SuperInstance/abstraction-planes)](LICENSE)
[![Fleet Status](https://img.shields.io/badge/fleet-status-active)](https://fleet.cocapn.io)

* Provides a structured approach to system design
* Identifies the "sweet spot" for abstraction (Plane 4)
* Offers a Guide, Reference, and Analyzer for implementation

Quick start: Explore the repo and start with Plane 4.

Architecture: A 6-plane stack from Intent to Metal, with Plane 4 as the primary focus.

[![Cocapn Fleet](https://img.shields.io/badge/cocapn-fleet-member)](https://fleet.cocapn.io)